searchData={"items":[{"type":"module","title":"YoloFastNMS","doc":"Runs Non-Maximum Suppression (NMS) on a given Nx tensor (or directly a binary) using a Rust NIF.\n\nCurrently, this implementation is specifically designed for a tensor with the shape `{84, 8400}` or `{1, 84, 8400}`,\nwhich corresponds to the output of a YOLO model trained on the COCO dataset.\n\n- The tensor's `8400` rows represent the detected objects.\n- The first 4 columns contain the bounding box parameters: `cx` (center x),\n  `cy` (center y), `w` (width), and `h` (height).\n- The remaining 80 columns represent the class probabilities.","ref":"YoloFastNMS.html"},{"type":"function","title":"YoloFastNMS.run/3","doc":"Runs Non-Maximum Suppression (NMS) on a tensor and returns a list of detected objects.","ref":"YoloFastNMS.html#run/3"},{"type":"function","title":"Parameters - YoloFastNMS.run/3","doc":"- `tensor`: An Nx tensor with shape `{84, 8400}` containing detection data\n- `prob_threshold`: Minimum probability threshold (0..1) for detection confidence\n- `iou_threshold`: IoU threshold (0..1) for overlap detection\n\nReturns a list of lists `[cx, cy, w, h, prob, class_idx]` where:\n- `cx`, `cy`: Center position coordinates of the detected object\n- `w`, `h`: Width and height of the bounding box\n- `prob`: Confidence score (between 0 and 1)\n- `class_idx`: Index of the detected class","ref":"YoloFastNMS.html#run/3-parameters"},{"type":"function","title":"YoloFastNMS.run_with_binary/3","doc":"Runs Non-Maximum Suppression (NMS) directly on a binary containing detection data.","ref":"YoloFastNMS.html#run_with_binary/3"},{"type":"function","title":"Parameters - YoloFastNMS.run_with_binary/3","doc":"- `tensor_binary`: A binary containing detection data in shape `{84, 8400}`\n- `prob_threshold`: Minimum probability threshold (0..1) for detection confidence\n- `iou_threshold`: IoU threshold (0..1) for overlap detection\n\nReturns a list of lists `[cx, cy, w, h, prob, class_idx]` where:\n- `cx`, `cy`: Center position coordinates of the detected object\n- `w`, `h`: Width and height of the bounding box\n- `prob`: Confidence score (between 0 and 1)\n- `class_idx`: Index of the detected class","ref":"YoloFastNMS.html#run_with_binary/3-parameters"},{"type":"extras","title":"YoloFastNMS","doc":"# YoloFastNMS\n\nA fast Non-Maximum Suppression (NMS) implementation in Rust for YOLO object detection outputs. This library is designed as a companion to the [`yolo`](https://github.com/poeticoding/yolo_elixir) library, specifically optimizing one of the most computationally intensive parts of the YOLO detection pipeline in Elixir/Nx, running much faster (~100x, ~4ms vs ~400ms on my MacBook Air M3)!\n\nThe NMS operation is crucial for filtering overlapping bounding boxes in object detection, but is computationally expensive when implemented in Elixir/Nx. This Rust NIF implementation provides significant speed improvements over the pure Elixir version, helping achieve near real-time performance for object detection tasks.\n\nThe current version is specifically built around YOLOv8 models trained on the COCO dataset, which outputs tensors in the shape of `{84, 8400}` (4 bounding box coordinates + 80 class probabilities × 8400 detections). The library efficiently filters these detections based on confidence scores `prob_threshold` and Intersection over Union (IoU) `iou_threshold` thresholds. Future development will focus on making the number of classes and detections dynamic, enabling compatibility with different YOLO and custom models.","ref":"readme.html"},{"type":"extras","title":"Installation - YoloFastNMS","doc":"```elixir\ndef deps do\n  [\n    {:yolo_fast_nms, \"~> 0.1.0\"}\n  ]\nend\n```","ref":"readme.html#installation"},{"type":"extras","title":"Stand-alone usage - YoloFastNMS","doc":"```elixir\n{84, 8400} = tensor_nx.shape\niex> YoloFastNMS.run(tensor_nx, 0.4, 0.5)\n[\n  [cx, cy, w, h, prob, class_idx]\n  ...\n] \n```","ref":"readme.html#stand-alone-usage"},{"type":"extras","title":"With YOLO library - YoloFastNMS","doc":"```elixir\nmodel = YOLO.load(...)\n\nYOLO.detect(mat, nms_fun: &YoloFastNMS.run/3)\n```","ref":"readme.html#with-yolo-library"}],"proglang":"elixir","content_type":"text/markdown","producer":{"name":"ex_doc","version":"0.35.1"}}